pub struct ListObjectsV2Params {
pub delimiter: Option<String>,
pub start_after: Option<String>,
pub continuation_token: Option<String>,
pub max_keys: Option<u32>,
pub prefix: Option<String>,
pub encoding_type: Option<String>,
pub fetch_owner: Option<bool>,
/* private fields */
}Expand description
Query parameters for ListObjectsV2, includes the required list-type=2 parameter
Fields
delimiter: Option<String>Character used to group object names. All object names containing the specified prefix, objects between the first occurrence of the delimiter character are treated as a group of elements
start_after: Option<String>Set to start returning objects alphabetically after start_after. start_after is used to implement pagination, parameter length must be less than 1024 bytes
continuation_token: Option<String>Specify that the List operation should start from this token. You can get this token from NextContinuationToken in ListObjectsV2 (GetBucketV2) results
max_keys: Option<u32>Specify the maximum number of objects to return. Value: greater than 0 and less than or equal to 1000, default: 100
prefix: Option<String>Limit returned file keys to those with prefix as a prefix. Parameter length must be less than 1024 bytes
encoding_type: Option<String>Encode the returned content and specify the encoding type. Optional value: url
fetch_owner: Option<bool>Specify whether to include owner information in the results. Default: false